## $Id: browser.py 10691 2013-11-04 09:19:39Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from zope.i18n import translate
from zope.component import getUtility
from hurry.workflow.interfaces import IWorkflowInfo
from waeup.kofa.interfaces import ADMITTED
from waeup.kofa.browser.layout import UtilityView
from waeup.kofa.students.interfaces import IStudentsUtils
from waeup.kofa.widgets.datewidget import FriendlyDatetimeDisplayWidget
from waeup.kofa.students.browser import (
    StartClearancePage, BedTicketAddPage, ExportPDFAdmissionSlipPage)
from waeup.kwarapoly.students.interfaces import (
    ICustomStudent, ICustomStudentBase)
from waeup.kwarapoly.interfaces import MessageFactory as _
from waeup.kofa.students.workflow import (
    ADMITTED, PAID, REQUESTED, RETURNING, CLEARED, REGISTERED,
    VALIDATED, GRADUATED, TRANSCRIPT, CREATED, CLEARANCE)
from kofacustom.nigeria.students.browser import (
    NigeriaOnlinePaymentDisplayFormPage,
    NigeriaOnlinePaymentAddFormPage,
    NigeriaExportPDFPaymentSlipPage,
    NigeriaStudentClearanceEditFormPage,
    )

from waeup.kwarapoly.students.interfaces import ICustomStudentOnlinePayment

class CustomOnlinePaymentDisplayFormPage(NigeriaOnlinePaymentDisplayFormPage):
    """ Page to view an online payment ticket
    """
    grok.context(ICustomStudentOnlinePayment)
    form_fields = grok.AutoFields(ICustomStudentOnlinePayment).omit(
        'provider_amt', 'gateway_amt', 'thirdparty_amt', 'p_item')
    form_fields[
        'creation_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')
    form_fields[
        'payment_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')

class CustomOnlinePaymentAddFormPage(NigeriaOnlinePaymentAddFormPage):
    """ Page to add an online payment ticket
    """
    form_fields = grok.AutoFields(ICustomStudentOnlinePayment).select(
        'p_category')

class CustomExportPDFPaymentSlipPage(NigeriaExportPDFPaymentSlipPage):
    """Deliver a PDF slip of the context.
    """
    grok.context(ICustomStudentOnlinePayment)
    form_fields = grok.AutoFields(ICustomStudentOnlinePayment).omit(
        'provider_amt', 'gateway_amt', 'thirdparty_amt', 'p_item')
    form_fields['creation_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')
    form_fields['payment_date'].custom_widget = FriendlyDatetimeDisplayWidget('le')

class CustomStartClearancePage(StartClearancePage):

    with_ac = False

class CustomStudentClearanceEditFormPage(NigeriaStudentClearanceEditFormPage):
    """ View to edit student clearance data by student
    """

    def dataNotComplete(self):
        return False

class BedTicketAddPage(BedTicketAddPage):
    """ Page to add an online payment ticket
    """
    buttonname = _('Create bed ticket')
    notice = ''
    with_ac = False

class CustomExportPDFAdmissionSlipPage(ExportPDFAdmissionSlipPage):
    """Deliver a PDF Admission slip.
    """
    grok.context(ICustomStudent)

    omit_fields = ('date_of_birth',)

    form_fields = grok.AutoFields(ICustomStudent).select('student_id', 'reg_number')

    def render(self):
        if self.context.state in (CREATED, ADMITTED,
                                  CLEARANCE, REQUESTED, CLEARED):
            self.flash('Not allowed.')
            self.redirect(self.url(self.context))
            return
        students_utils = getUtility(IStudentsUtils)
        return students_utils.renderPDFAdmissionLetter(self,
            self.context.student, omit_fields=self.omit_fields)

class ExportPDFAdmissionNotificationPage(UtilityView, grok.View):
    """Deliver a PDF Admission nostification slip.
    """
    grok.context(ICustomStudent)
    grok.name('admission_notification.pdf')
    grok.require('waeup.viewStudent')
    prefix = 'form'
    label = 'Notification of Provisional Admission'

    omit_fields = ('date_of_birth',)

    form_fields = grok.AutoFields(ICustomStudent).select(
        'student_id', 'reg_number', 'sex', 'lga')

    def render(self):
        if self.context.state not in (ADMITTED, CLEARANCE, REQUESTED, CLEARED):
            self.flash('Not allowed.')
            self.redirect(self.url(self.context))
            return
        students_utils = getUtility(IStudentsUtils)
        pre_text = ''
        post_text = '<strong>Instructions for Freshers</strong>'
        return students_utils.renderPDFAdmissionLetter(self,
            self.context.student, omit_fields=self.omit_fields,
            pre_text=pre_text, post_text=post_text)
